==> sdlskk-0.1.tar.gz: sdlskk-0.1/testdict.c <==
#include <stdio.h>
#include <stdlib.h>
#include "sdlskk.h"
#include "sdlskk_internal.h"

void print_str( SDLSKK_Char* str )
{
  int i,j;
  unsigned char b;
  for( i=0; str[i] != 0; ++i ){
    for( j=3; j>=0; --j ){
      b = ( str[i] & ( ((unsigned int)0xFF) << j*8 ) ) >> j*8;
      if( b != 0 )
	putchar( b );
    }
  }
}

void print_Dict( SDLSKK_Dictionary *dict )
{
  SDLSKK_Map* map = dict->map;
  int i;
  SDLSKK_HashElement* hel;
  SDLSKK_ListElement* lel;
  for( i=0; i<map->table_size; i++ ){
    for( hel = map->table[i]; hel != NULL; hel = hel->next ){
      print_str( hel->key );
      putchar( '\n' );
      for( lel = hel->vals->begin->next; lel != hel->vals->end; lel = lel->next ){
	putchar( ' ' );
	print_str( lel->val );
	putchar( '\n' );
      }
    }
  }
}


void check_DictItem( SDLSKK_Dictionary* dict )
{
  SDLSKK_DictionaryItem *item;
  char command[1024];
  
  item = SDLSKK_Dict_get( dict, SDLSKK_Str_new2( "" ) );

  print_str( item->hiragana );
  putchar( '\n' );
  
  for(;;){
    fgets( command, sizeof(command), stdin );
    switch( command[0] ){
    case 'r':
      SDLSKK_DictItem_reset( item );
      print_str( SDLSKK_DictItem_get_current( item ) );
      putchar( '\n' );
      break;
    case 'n':
      SDLSKK_DictItem_next( item );
      print_str( SDLSKK_DictItem_get_current( item ) );
      putchar( '\n' );
      break;
    case 'q':
      return ;
    }
  }
  
    
}

int main()
{
  SDLSKK_Dictionary* dict = SDLSKK_Dict_new( "test_jisyo" );
  print_Dict( dict );
  check_DictItem( dict );
  return 0;
}

==> sdlskk-0.2.tar.gz: sdlskk-0.2/testdict.c <==
#include <stdio.h>
#include <stdlib.h>
#include "sdlskk.h"
#include "sdlskk_internal.h"

void print_str( SDLSKK_Char* str )
{
  int i,j;
  unsigned char b;
  for( i=0; str[i] != 0; ++i ){
    for( j=3; j>=0; --j ){
      b = ( str[i] & ( ((unsigned int)0xFF) << j*8 ) ) >> j*8;
      if( b != 0 )
	putchar( b );
    }
  }
}

void print_Dict( SDLSKK_Dictionary *dict )
{
  SDLSKK_Map* map = dict->map;
  int i;
  SDLSKK_HashElement* hel;
  SDLSKK_ListElement* lel;
  for( i=0; i<map->table_size; i++ ){
    for( hel = map->table[i]; hel != NULL; hel = hel->next ){
      print_str( hel->key );
      putchar( '\n' );
      for( lel = hel->vals->begin->next; lel != hel->vals->end; lel = lel->next ){
	putchar( ' ' );
	print_str( lel->val );
	putchar( '\n' );
      }
    }
  }
}


void check_DictItem( SDLSKK_Dictionary* dict )
{
  SDLSKK_DictionaryItem *item;
  char command[1024];
  
  item = SDLSKK_Dict_get( dict, SDLSKK_Str_new2( "" ) );

  print_str( item->hiragana );
  putchar( '\n' );
  
  for(;;){
    fgets( command, sizeof(command), stdin );
    switch( command[0] ){
    case 'r':
      SDLSKK_DictItem_reset( item );
      print_str( SDLSKK_DictItem_get_current( item ) );
      putchar( '\n' );
      break;
    case 'n':
      SDLSKK_DictItem_next( item );
      print_str( SDLSKK_DictItem_get_current( item ) );
      putchar( '\n' );
      break;
    case 'q':
      return ;
    }
  }
  
    
}

int main( int argc, char** argv )
{
  SDLSKK_Dictionary* dict = SDLSKK_Dict_new();
  SDLSKK_Dict_load( dict, "test_jisyo", 0 );
  print_Dict( dict );
  check_DictItem( dict );
  return 0;
}
